OverviewWindow = class(Turbine.UI.Window)
 
function OverviewWindow:Constructor()

  local width = 600;
  local height = 90;
  local x = Turbine.UI.Display:GetWidth()/2 - width/2;
  local y = 0;

  Turbine.UI.Window.Constructor(self);
  
  self:SetSize(width,height);
  self:SetPosition(x,y);
  self:SetText("OverviewWindow");
  self:SetWantsKeyEvents(true);
    
  if (not dataLoaded) then
    points_total = tonumber(initWindow:GetData());
  end
  
  initWindow:SetVisible(false);
  initWindow = nil;

	self.bar_start = width/10 + 3;
	self.bar_end = width - width/10 - 3
	self.bar_length = self.bar_end - self.bar_start;
	
	self.empty_bar = Turbine.UI.Label();
	self.empty_bar:SetParent(self);
	self.empty_bar:SetSize(self.bar_length,18);
	self.empty_bar:SetPosition(self.bar_start+3,25);
	self.empty_bar:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_empty.tga");
	
	self.filled_bar = Turbine.UI.Label();
	self.filled_bar:SetParent(self);
	self.filled_bar:SetSize(0,18);
	self.filled_bar:SetPosition(self.bar_start+3,25);
	self.filled_bar:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_filled.tga");

	self.percentage = Turbine.UI.Label();
	self.percentage:SetParent(self);
  self.percentage:SetSize(width,18);
  self.percentage:SetPosition(0,25);
  self.percentage:SetFont(Turbine.UI.Lotro.Font.Verdana12);
  self.percentage:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
	
	self.left_end = Turbine.UI.Label();
	self.left_end:SetParent(self);
	self.left_end:SetSize(6,18);
	self.left_end:SetPosition(self.bar_start-3,25);
	
	self.right_end = Turbine.UI.Label();
	self.right_end:SetParent(self);
	self.right_end:SetSize(6,18);
	self.right_end:SetPosition(self.bar_end-3,25);
  ------------------------------------------------------------
  self.label_points = Turbine.UI.Label();
  self.label_points:SetParent(self);
  self.label_points:SetSize(200,20);
  self.label_points:SetForeColor(Turbine.UI.Color(245/255,222/255,147/255));
  self.label_points:SetPosition(width/2-self.label_points:GetSize()/2,40);
	self.label_points:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
  self.label_points:SetFont(Turbine.UI.Lotro.Font.TrajanPro15);
  ------------------------------------------------------------
  self.MovePanel = Turbine.UI.Control();
  self.MovePanel:SetParent(self);
  self.MovePanel:SetSize(width,19);
  self.MovePanel:SetBackground("PvMP_Plus/Resources/MoveTopBar.tga");
  
  self.MoveIcon = Turbine.UI.Control();
  self.MoveIcon:SetParent(self.MovePanel);
  self.MoveIcon:SetSize(19,19);
  self.MoveIcon:SetBackground("PvMP_Plus/Resources/MoveIcon.tga");
  self.MoveIcon:SetMouseVisible(false);
  
  self.MoveText = Turbine.UI.Label();
  self.MoveText:SetParent(self.MovePanel);
  self.MoveText:SetSize(width,12);
  self.MoveText:SetPosition(0,4);
  self.MoveText:SetFont(Turbine.UI.Lotro.Font.Verdana12);
  self.MoveText:SetText("PvMP+");
  self.MoveText:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
  self.MoveText:SetMouseVisible(false);
  
  self.MovePanel:SetVisible(false);
  
  self.Moving = false;

  self.MovePanel.MouseDown = function(sender,args)
    self.MoveX = args.X;
    self.MoveY = args.Y;
    self.Moving = true;
    self.MoveIcon:SetBackground("PvMP_Plus/Resources/MoveIcon_Pressed.tga");
    self.MovePanel:SetBackground("PvMP_Plus/Resources/MoveTopBar_Pressed.tga");
  end
    
  self.MovePanel.MouseUp = function(sender,args)
    self.Moving = false;
    self.MoveIcon:SetBackground("PvMP_Plus/Resources/MoveIcon.tga");
    self.MovePanel:SetBackground("PvMP_Plus/Resources/MoveTopBar.tga");
  end
    
  self.MovePanel.MouseMove = function(sender,args)
    if self.Moving then
      local newLeft = self:GetLeft() - (self.MoveX - args.X);
      local newTop = self:GetTop() - (self.MoveY - args.Y);
      if newLeft < 0 then newLeft = 0 end;
      if newTop < 0 then newTop = 0 end;
      if newLeft > (Turbine.UI.Display.GetWidth() - self:GetWidth()) then
        newLeft = Turbine.UI.Display.GetWidth() - self:GetWidth() end;
      if newTop > (Turbine.UI.Display.GetHeight() - self:GetHeight()) then
        newTop = Turbine.UI.Display.GetHeight() - self:GetHeight() end;
      self:SetPosition(newLeft,newTop);
    end
  end

  self.KeyDown = function(sender,args) 
    if (args.Action == Turbine.UI.Lotro.Action.ToggleHUD) then
      self:SetVisible(not self:IsVisible()); -- toggle visibility of Window
    elseif (args.Action == Turbine.UI.Lotro.Action.RepositionUI) then
      self.MovePanel:SetVisible(not self.MovePanel:IsVisible()); -- toggle visibility of MovePanel
    end
  end
  
  self:Update();
  self:SetVisible(true);
end


function OverviewWindow:Update()
  self.label_points:SetText(L.Overview_Points .. points_total);
	
	for i=0, 14 do
		if (points_total >= Ranks[i] and points_total < Ranks[i+1]) then
			local rank_difference = Ranks[i+1] - Ranks[i];
			local points_since_rankup = points_total - Ranks[i];
			local percentage_done = points_since_rankup / rank_difference;
			self:UpdateProgressBar(percentage_done)
			return;
		end
	end

	self:UpdateProgressBar(1) -- Rank 15
end


function OverviewWindow:UpdateProgressBar(percentage_done)

	self.percentage:SetText(math.floor(percentage_done*10000)/100 .. "%");

	local filled_pixel = math.floor(self.bar_length * percentage_done);
	self.filled_bar:SetSize(filled_pixel,18);
	if (filled_pixel == self.bar_length) then
		self.left_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_left_4.tga");
		self.right_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_right_4.tga");
	elseif (filled_pixel == self.bar_length - 1) then
		self.left_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_left_4.tga");
		self.right_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_right_3.tga");
	elseif (filled_pixel == self.bar_length - 2) then
		self.left_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_left_4.tga");
		self.right_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_right_2.tga");
	elseif (filled_pixel == 2) then
		self.left_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_left_3.tga");
		self.right_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_right_1.tga");
	elseif (filled_pixel == 1) then
		self.left_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_left_2.tga");
		self.right_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_right_1.tga");
	elseif (filled_pixel == 0) then
		self.left_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_left_1.tga");
		self.right_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_right_1.tga");
	else
		self.left_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_left_4.tga");
		self.right_end:SetBackground("PvMP_Plus/Resources/Progress_Bar/bar_end_right_1.tga");
	end

	if (filled_pixel < self.bar_length-3) then
		self.filled_bar:SetSize(filled_pixel-3,18);
	else
		self.filled_bar:SetSize(self.bar_length-6,18);
	end
end